X-Git-Url: https://git.saurik.com/wxWidgets.git/blobdiff_plain/f18eaf2687ab42c97ccf469a2617306cadc0c6ef..f99bfeea731ef625de3efbb50bf0c670d8d52926:/include/wx/vlbox.h

diff --git a/include/wx/vlbox.h b/include/wx/vlbox.h
index aa3618c2a1..f5ce8b88c5 100644
--- a/include/wx/vlbox.h
+++ b/include/wx/vlbox.h
@@ -226,11 +226,11 @@ protected:
     // current
     virtual void OnDrawBackground(wxDC& dc, const wxRect& rect, size_t n) const;
 
     // we implement OnGetLineHeight() in terms of OnMeasureItem() because this
     // allows us to add borders to the items easily
     //
     // this function is not supposed to be overridden by the derived classes
-    virtual wxCoord OnGetLineHeight(size_t line) const;
+    virtual wxCoord OnGetRowHeight(size_t line) const;
 
 
     // event handlers
@@ -226,11 +226,11 @@ protected:
     virtual void OnDrawBackground(wxDC& dc, const wxRect& rect, size_t n) const;
 
-    // we implement OnGetLineHeight() in terms of OnMeasureItem() because this
+    // we implement OnGetRowHeight() in terms of OnMeasureItem() because this
     // allows us to add borders to the items easily
     //